==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/UseCase/GetRoleUsers.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] ?: array()) + array("_f4532747e1604b" . "7bf86d299f9b9b0" . "583" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc3Npb24gdG8g" . "dmlldyB0aGlzIHJvbGU="), "_94c782c8180766e1ff18" . "70975a93053d" => base64_decode("Um9sZSB" . "ub3QgZm" . "91bmQ="));
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;
class GetRoleUsers
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $role_repository;
    
    
    
    
    protected $get_users;
    
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db, GetUsers $get_users)
    {
        $this->acl = $acl;
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
        $this->get_users = $get_users;
    }
    
    
    
    
    
    
    
    
    
    public function GetRoleUsers(SecurityContext $context, int $role_id, UserFilter $_03e9164d0a343b742df4793268b80767) : array
    {
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->role_repository->find($role_id);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_94c782c8180" . "766e1ff18709" . "75a93053d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f4532747" . "e1604b7bf" . "86d299f9b" . "9b0583"]);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        $_03e9164d0a343b742df4793268b80767->SetRoleIds($role_id);
        return $this->get_users->GetUsers($_03e9164d0a343b742df4793268b80767);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/UseCase/GetRoleUsers.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_f453274" . "7e1604b7" . "bf86d299" . "f9b9b058" . "3" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlc" . "m1pc3Npb24gdG8gdmlldyB0aG" . "lzIHJvbGU="), "_94c782c" . "8180766e" . "1ff18709" . "75a93053" . "d" => base64_decode("Um9sZSBub3QgZm91b" . "mQ="));
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\Role;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Exception\PermissionException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\RoleRepository;
class GetRoleUsers
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $role_repository;
    
    
    
    
    protected $get_users;
    
    
    
    
    
    
    public function __construct(PeopleAcl $acl, RoleRepository $_90f6cb30a269a622b4c838bfd5a0a5db, GetUsers $get_users)
    {
        $this->acl = $acl;
        $this->role_repository = $_90f6cb30a269a622b4c838bfd5a0a5db;
        $this->get_users = $get_users;
    }
    
    
    
    
    
    
    
    
    
    public function GetRoleUsers(SecurityContext $context, int $role_id, UserFilter $_03e9164d0a343b742df4793268b80767) : array
    {
        
        
        
        
        $_d1071a032215f0eb5c4a8ef175f7049d = $this->role_repository->find($role_id);
        if (!$_d1071a032215f0eb5c4a8ef175f7049d) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_94c782c8180766e1ff1" . "870975a93053d"]);
        }
        if (!$this->acl->CanViewRole($context, $_d1071a032215f0eb5c4a8ef175f7049d)) {
            throw new PermissionException($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_f4532747e1604b7bf86d299f9b9b0" . "583"]);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        $_03e9164d0a343b742df4793268b80767->SetRoleIds($role_id);
        return $this->get_users->GetUsers($_03e9164d0a343b742df4793268b80767);
    }
}
